@@ -40,16 +40,20 @@ setMethod(
         phase[i, j] <- paste(z[i], z[j], sep = "-")
       }
     }
+    phase <- as.character(phase)
+    start <- as.numeric(start)
+    stop <- as.numeric(stop)
 
-    ## Remove false results
-    drop <- start > stop
-    stop[drop] <- NA
-    start[drop] <- NA
+    ## Remove wrong results
+    keep <- which(start <= stop)
+    phase <- phase[keep]
+    start <- start[keep]
+    stop <- stop[keep]
 
     .TimeRange(
-      start = start,
-      end = stop,
-      labels = phase,
+      .Id = as.character(phase),
+      .Start = aion::as_fixed(start),
+      .End = aion::as_fixed(stop),
       hash = get_hash(x)
     )
   }
